package cn.com.ctop.toutiao.modules.report.mapper;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import org.apache.ibatis.annotations.Param;

import java.util.List;

public interface BytedanceNewPlanReportMapper {

    List<JSONObject> queryBytedanceNewPlanGroupByAccount(@Param("accountIds") JSONArray accountIds, @Param("startDate") String startDate, @Param("endDate") String endDate, @Param("target") String target, @Param("order") String order);

    List<JSONObject> queryBytedanceNewPlanGroupByStatDate(@Param("accountIds") JSONArray accountIds, @Param("startDate") String startDate, @Param("endDate") String endDate);

    List<JSONObject> queryBytedanceNewPlanGroupByMonth(@Param("accountIds") JSONArray accountIds, @Param("startDate") String startDate, @Param("endDate") String endDate);

    JSONObject querySumNewPlanBy(@Param("accountIds") JSONArray accountIds, @Param("startDate") String startDate, @Param("endDate") String endDate);

    List<JSONObject> queryAllOperator();

    JSONArray queryAccountIdsByUserId(String userId);

    JSONArray queryAccountIdsByMedia();

}
